@@ -14,14 +14,15 @@ function fix_git(){
 }
 
 function fix_gits(){
-    ${wd}/ensure_gits.sh legacy_0.2.8.3 || return $?
+    ${wd}/ensure_gits.sh legacy_0.2.8 || return $?
 
     set -x
+    # On merge conflicts here: run update_gits.sh, that sorts things out
 
     fix_git winlibs d03e20bf8973a6cbd1e0ecb47dd8333c5614b139 || return $?
-    fix_git codeblocks 5ab4c626eb7cfa692a0bda7dbf26fed3721e4aa3 || return $?
-    fix_git ubuntu c4910e573fefd62f8241d4a484482ab8bb205b4d || return $?
+    fix_git codeblocks c633fa6599c888d92156648a882d76f3ca15b610 || return $?
     fix_git steam-art 7b3930ab85a3dfbb1caffaa17442b670c823f314 || return $?
+    fix_git pkg2appimage 678e5e14122f14a12c54847213585ea803e1f0e1 || return $?
 }
 
 if ! fix_gits; then
