@@ -44,13 +44,14 @@ function fix_gits(){
     \${wd}/ensure_gits.sh ${branch} || return \$?
 
     set -x
+    # On merge conflicts here: run update_gits.sh, that sorts things out
 
 EOF
 
 fix_git winlibs
 fix_git codeblocks
-fix_git ubuntu
 fix_git steam-art
+fix_git pkg2appimage
 
 cat >> ${of} <<EOF
 }
@@ -66,18 +67,3 @@ chmod 755 ${of}
 
 ${of}
 
-#set -x
-
-# fetch rebrand script from ubuntu daily builds
-rd=${wd}/../build/rebrand_debian_core.sh
-git -C ${download_dir}/ubuntu show origin/${UBUNTU_BRANCH}-dailydeb:rebrand.sh |\
-    sed -e s/PACKAGE=.*/PACKAGE=\${PACKAGE_NAME}/ \
-	-e s/NAME=.*/NAME=\${PACKAGE_TITLE}/ \
-	-e "s/pushd.*/pushd debian/" |\
-    grep -v topdir | grep -v branch > ${rd} >\
-	 ${rd}
-
-#cat ${rd}
-chmod 755 ${rd}
-
-
