@@ -45,7 +45,6 @@ class eNetGameObject:public eGameObject,public nNetObject{
 protected:
     REAL lastClientsideAction;
     REAL lastAttemptedSyncTime;
-    REAL pingOverflow;
 
     tCHECKED_PTR(ePlayerNetID)    player; // the player controlling this cycle.
     // NULL means the AI.
@@ -75,7 +74,7 @@ public:
     eNetGameObject(eGrid *grid, const eCoord &pos,const eCoord &dir,ePlayerNetID* p,bool autodelete=false);
     eNetGameObject(nMessage &m);
 
-    virtual void RemoveFromGame(); // just remove it from the lists and unregister it
+    virtual void DoRemoveFromGame(); // just remove it from the lists and unregister it
 
     virtual void WriteCreate(nMessage &m);
     virtual void WriteSync(nMessage &m);
@@ -101,7 +100,7 @@ public:
     void clientside_action(){lastClientsideAction=lastTime;}
 
     virtual REAL Lag() const;
-
+    virtual REAL LagThreshold() const;
 };
 
 nMessage &operator << (nMessage &m, const eCoord &x);
