@@ -31,20 +31,21 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "nConfig.h"
 
 #include <set>
+#include <climits>
 
-tString & operator << ( tString &s, const eTeam & team)
+tString & operator << ( tString &s, const eTeam * team)
 {
-    if ( !(&team) )
+    if ( !team )
         return s << tOutput("$player_spectator_message");
     else
-        return s << team.GetColoredName();
+        return s << team->GetColoredName();
 }
-std::ostream & operator << ( std::ostream &s, const eTeam & team)
+std::ostream & operator << ( std::ostream &s, const eTeam * team)
 {
-    if ( !(&team) )
+    if ( !team )
         return s << tOutput("$player_spectator_message");
     else
-        return s << team.GetColoredName();
+        return s << team->GetColoredName();
 }
 
 #define TEAMCOLORS 8
@@ -75,7 +76,7 @@ static tString se_team_name[TEAMCOLORS]=
 // static tList<eTeam> se_ColoredTeams;
 static eTeam * se_ColoredTeams[TEAMCOLORS]={0,0,0,0,0,0,0,0};
 
-static int IMPOSSIBLY_LOW_SCORE=(-1 << 31);
+static int IMPOSSIBLY_LOW_SCORE=INT_MIN;
 
 // class that creates config items for one team
 // TEAM_(NAME|RED|GREEN|BLUE)_X
@@ -216,11 +217,21 @@ void eTeam::UpdateProperties()
         RequestSync();
 }
 
+static eLadderLogWriter se_teamRenamedWriter("TEAM_RENAMED", true);
+static eLadderLogWriter se_teamCreateWriter("TEAM_CREATED", true);
+static eLadderLogWriter se_teamDestroyWriter("TEAM_DESTROYED", true);
+static eLadderLogWriter se_teamAddWriter("TEAM_PLAYER_ADDED", true);
+static eLadderLogWriter se_teamRemoveWriter("TEAM_PLAYER_REMOVED", true);
+
 // update name and color
 void eTeam::UpdateAppearance()
 {
+    bool empty = false;
+
     unsigned short oldr = r, oldg = g, oldb = b;
 
+    tString oldName = name;
+
     ePlayerNetID* oldest = OldestHumanPlayer();
     if ( !oldest )
     {
@@ -307,7 +318,31 @@ void eTeam::UpdateAppearance()
         // empty team
         name = tOutput("$team_empty");
         r = g = b = 7;
+        empty = true;
     }
+    
+    tString oldNameFiltered = ePlayerNetID::FilterName(oldName);
+    tString newNameFiltered = ePlayerNetID::FilterName(name);
+    if( oldNameFiltered != newNameFiltered )
+    {
+        if( !empty && !lastEmpty_ )
+        {
+            se_teamRenamedWriter << oldNameFiltered << newNameFiltered;
+            se_teamRenamedWriter.write();
+        }
+        else if( !empty )
+        {
+            se_teamCreateWriter << newNameFiltered;
+            se_teamCreateWriter.write();
+        }
+        else if( !lastEmpty_ )
+        {
+            LogScoreDifference( oldNameFiltered );
+            se_teamDestroyWriter << oldNameFiltered;
+            se_teamDestroyWriter.write();
+        }
+    }
+    lastEmpty_ = empty;
 
     if ( nSERVER == sn_GetNetState() )
         RequestSync();
@@ -390,16 +425,16 @@ void eTeam::Invite( ePlayerNetID * player )
 void eTeam::UnInvite( ePlayerNetID * player )
 {
     tASSERT( player );
+    size_t wasInvited = player->invitations_.erase( this );
     if ( player->CurrentTeam() == this && this->IsLocked() )
     {
         sn_ConsoleOut( tOutput( "$invite_team_kick", player->GetColoredName(), Name() ) );
         player->SetTeam(0);
     }
-    else
+    else if ( wasInvited )
     {
         sn_ConsoleOut( tOutput( "$invite_team_uninvite", player->GetColoredName(), Name() ) );
     }
-    player->invitations_.erase( this );
 }
 
 // check if a player is invited
@@ -522,15 +557,21 @@ void eTeam::LogScoreDifferences( void )
 static eLadderLogWriter se_roundScoreTeamWriter("ROUND_SCORE_TEAM", true);
 
 void eTeam::LogScoreDifference( void )
+{
+    LogScoreDifference( Name() );
+}
+
+void eTeam::LogScoreDifference( const tString & teamName )
 {
     if ( lastScore_ > IMPOSSIBLY_LOW_SCORE && IsHuman() )
     {
         tString ret;
         int scoreDifference = score - lastScore_;
         lastScore_ = IMPOSSIBLY_LOW_SCORE;
-        se_roundScoreTeamWriter << scoreDifference << ePlayerNetID::FilterName( Name() );
+        se_roundScoreTeamWriter << scoreDifference << ePlayerNetID::FilterName( teamName );
         se_roundScoreTeamWriter.write();
     }
+    
 }
 
 void eTeam::SwapTeamsNo(int a,int b){
@@ -856,6 +897,24 @@ void eTeam::WritePlayers( eLadderLogWriter & writer, const eTeam *team )
     }
 }
 
+static eLadderLogWriter se_positionWriter( "POSITIONS", false );
+void eTeam::WriteLaunchPositions()
+{
+    for ( int i = teams.Len() - 1; i >= 0; --i )
+    {
+        eTeam *team = teams(i);
+        
+        // AI teams are boring.
+        if ( !team->IsHuman() )
+            continue;
+
+        se_positionWriter << ePlayerNetID::FilterName( team->Name() );
+        for ( int j = 0; j < team->players.Len(); j++ )
+            se_positionWriter << team->players( j )->GetLogName();
+        se_positionWriter.write();
+    }
+}
+
 // inquire or set the ability to use a color as a team name
 bool eTeam::NameTeamAfterColor ( bool wish )
 {
@@ -930,6 +989,10 @@ void eTeam::AddPlayer    ( ePlayerNetID* player )
         */
     }
 
+
+    se_teamAddWriter << ePlayerNetID::FilterName( name ) << player->GetLogName();
+    se_teamAddWriter.write();
+
     // anounce joining if there are is more than one member now or if the team is color-named
     if ( sn_GetNetState() != nCLIENT )
     {
@@ -999,6 +1062,9 @@ void eTeam::AddPlayerDirty   ( ePlayerNetID* player )
     }
 
     player->UpdateName();
+
+    se_teamAddWriter << ePlayerNetID::FilterName( name ) << player->GetLogName();
+    se_teamAddWriter.write();
 }
 
 // deregister a player
@@ -1021,11 +1087,17 @@ void eTeam::RemovePlayerDirty ( ePlayerNetID* player )
     players.Remove ( player, player->teamListID );
     player->currentTeam = NULL;
 
+    se_teamRemoveWriter << ePlayerNetID::FilterName( name ) << player->GetLogName();
+    se_teamRemoveWriter.write();
+
     // remove team from list
     if ( listID >= 0 && players.Len() == 0 )
     {
         teams.Remove( this, listID );
 
+        // correctly log removal
+        UpdateAppearance();
+
         // don't forget the colored team list
         if ( colorID >= 0 )
         {
@@ -1393,6 +1465,7 @@ eTeam::eTeam()
     maxPlayersLocal = maxPlayers;
     maxImbalanceLocal = maxImbalance;
     r = g = b = 32; // initialize color so it will be updated, guaranteed
+    lastEmpty_=true;
     Update();
 }
 
@@ -1408,12 +1481,16 @@ eTeam::eTeam(nMessage &m)
     maxPlayersLocal = maxPlayers;
     maxImbalanceLocal = maxImbalance;
     r = g = b = 32; // initialize color so it will be updated, guaranteed
+    lastEmpty_=true;
     Update();
 }
 
 // destructor
 eTeam::~eTeam()
 {
+    // one last time
+    UpdateAppearance();
+
     if ( listID >= 0 )
         teams.Remove( this, listID );
 
@@ -1553,11 +1630,11 @@ void eTeam::Shuffle( int startID, int stopID )
         return;
     
     ePlayerNetID *player = players[startID];
-    eShuffleSpamTester & spam = player->shuffleSpam;
+    eShuffleSpamTester & spam = player->GetShuffleSpam();
     
     if ( spam.ShouldAnnounce() )
     {
-        sn_ConsoleOut( player->shuffleSpam.ShuffleMessage( player, startID + 1, stopID + 1 ) );
+        sn_ConsoleOut( spam.ShuffleMessage( player, startID + 1, stopID + 1 ) );
     }
 
     // simply swap the one player over all the players in between.
