@@ -32,8 +32,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "nNetObject.h"
 #include "tList.h"
 
-tString & operator << ( tString&, const eTeam&);
-std::ostream & operator << ( std::ostream&, const eTeam&);
+tString & operator << ( tString&, const eTeam*);
+std::ostream & operator << ( std::ostream&, const eTeam*);
 
 template<class T> class nConfItem;
 
@@ -45,6 +45,8 @@ protected:							// protected attributes
     int score;						// score the team has accumulated
     int lastScore_;                 //!< score from the beginning of the round
 
+    bool lastEmpty_;                //!< flag indicating whether the team was empty on the last call to UpdateAppearance
+
     int numHumans;					// number of human players on the team
     int numAIs;						// number of AI players on the team
 
@@ -93,6 +95,7 @@ public:							// public configuration options
     static void Enforce( int minTeams, int maxTeams, int maxImbalance );
     
     static void WritePlayers( eLadderLogWriter & writer, const eTeam *team );
+    static void WriteLaunchPositions(); // Logs player positions to ladderlog.txt
 public:												// public methods
     static void	EnforceConstraints();					// make sure the limits on team number and such are met
 
@@ -195,11 +198,6 @@ public:												// public methods
     // receives the control message. the data written to the message created
     // by *NewControlMessage() can be read directly from m.
 
-    // shall the server accept sync messages from the clients?
-    virtual bool AcceptClientSync() const	{
-        return false;
-    }
-
     // con/desstruction
     eTeam();											// default constructor
     eTeam(nMessage &m);									// remote constructor
@@ -207,6 +205,7 @@ public:												// public methods
 
 private:
     void 	 		RemovePlayerDirty( ePlayerNetID* player );				// just remove a player from the player list, no messages, no balancing
+    void LogScoreDifference( const tString & teamName );
 };
 
 #endif
