@@ -580,6 +580,7 @@ void nNetObject::TakeOwnership(){
     if ( !this->createdLocally )
     {
         this->createdLocally = true;
+        this->owner = sn_myNetID;
         //		AddRef();
     }
 }
@@ -1971,7 +1972,9 @@ void sn_Sync(REAL timeout,bool sync_sn_netObjects, bool otherEnd){
             }
 
             // wait for all packets to be sent and the sync ack packet to be received
-            while ( sn_Connections[0].socket && ( sync_ack[0] == false || sn_Connections[0].ackPending>0 || sn_QueueLen(0)) &&
+            while ( sn_Connections[0].socket &&
+                    !tRecorder::DesyncedPlayback() &&
+                    ( sync_ack[0] == false || sn_Connections[0].ackPending>0 || sn_QueueLen(0)) &&
                     tSysTimeFloat()<endTime){
                 sn_Delay();
                 sn_Receive();
