@@ -226,7 +226,7 @@ void nServerInfo::CalcScore()
         score -= 400;
     }
 
-    score -= fabsf( this->Version().Max() - sn_MyVersion().Max() ) * 10;
+    score -= abs( this->Version().Max() - sn_MyVersion().Max() ) * 10;
 
     score += scoreBias_;
 }
@@ -2420,8 +2420,11 @@ nServerInfo* nServerInfo::GetRandomMaster()
     tASSERT( masterInfo );
 
     // store and return
-    masterInfo->Remove();
-    masterInfo->Insert( sn_masterList );
+    if(masterInfo)
+    {
+        masterInfo->Remove();
+        masterInfo->Insert( sn_masterList );
+    }
 
     return masterInfo;
 }
