@@ -73,12 +73,13 @@ public:
     typedef bool MessageCallback(const tOutput& message, const tOutput& interpretation, REAL timeout);
 
     // idle callback; called from various spots when the progam is waiting.
-    // return true if the waiting should be aborted
-    typedef bool IdleCallback();
+    // return true if the waiting should be aborted, parameter is true if input should
+    // actually be processed
+    typedef bool IdleCallback( bool );
 
     virtual ~tConsole();
 
-    tConsole & Print(tString s);
+    tConsole & Print(tString const & s);
 
     template<class T> tConsole & operator<<(const T&x){
         tColoredString s;
@@ -91,8 +92,9 @@ public:
     // give a message to the user
     static bool Message(const tOutput& message, const tOutput& interpetation, REAL timeout = -1);
 
-    // idle around a bit (return value true: abort whatever you're doing)
-    static bool Idle();
+    // idle around a bit (return value true: abort whatever you're doing),
+    // input value determines whether input is actually processed
+    static bool Idle( bool processInput );
 
     virtual tString ColorString(REAL r, REAL g, REAL b) const;
 
@@ -105,6 +107,7 @@ protected:
 private:
     static tConsole *s_betterConsole;
 
+    void PrintLine(tString const & s, int repetitions);
     virtual tConsole & DoPrint(const tString& s);
     virtual void DoCenterDisplay(const tString& s,REAL timeout=5,REAL r=1,REAL g=1,REAL b=1);
 };
